@@ -16,7 +16,7 @@ CREATE TABLE Tracks (
 	
 	Artist TEXT,
 	Performer TEXT,
-	AlbumTitle INTEGER,
+	AlbumTitle TEXT,
 	ReleaseDate Date,
 	ASIN TEXT,
 	Label TEXT,
@@ -36,7 +36,9 @@ CREATE TABLE Tracks (
 	Rating INTEGER,
 	NumberOfPlays INTEGER,
 	LastPlayedStamp INTEGER,
-	DateAddedStamp INTEGER
+	DateAddedStamp INTEGER,
+	
+	RemoteLookupStatus INTEGER
 );
 
 --IF TABLE NOT EXISTS Playlists;
