@@ -74,15 +74,36 @@ namespace Banshee.Base
     
         public static void ReloadEngine(IPlayerEngine engine)
         {
+            if(ActivePlayer == engine) {
+                return;
+            }
+        
             if(ActivePlayer != null) {
                 ActivePlayer.Dispose();
-                ActivePlayer = null;
             }
             
             ActivePlayer = engine;
             ActivePlayer.Initialize();
         }
         
+        public static void LoadEngineByExtension(string extension)
+        {
+            UnloadCdPlayer();
+            
+            foreach(IPlayerEngine engine in PlayerEngineLoader.Engines) {
+                if(engine.SupportedExtensions == null) {
+                    continue;
+                }
+                
+                foreach(string engine_ext in engine.SupportedExtensions) {
+                    if(engine_ext == extension) {
+                        ReloadEngine(engine);
+                        return;
+                    }
+                }       
+            }
+        }
+        
         public static void LoadCdPlayer()
         {
             if(ActivePlayer == AudioCdPlayer) {
@@ -119,6 +140,10 @@ namespace Banshee.Base
         public static IPlayerEngine PreferredPlayer {
             get {
                 return preferred_player;
+            } 
+            
+            set {
+                preferred_player = value;
             }
         }
         
