@@ -124,15 +124,21 @@ namespace MusicBrainz
         
         public string GetIDFromUrl(string url)
         {
+            if(url == null) {
+                return null;
+            }
+            
             byte [] buffer = new byte[64];
             mb_GetIDFromURL(handle, ToUtf8(url), buffer, buffer.Length);
-            return FromUtf8(buffer);
+            string id = FromUtf8(buffer);
+            int offset = id.IndexOf('#') + 1;
+            return (offset >= 0) ? id.Substring(offset) : id;
         }
         
         public string GetID(string id)
         {
-            return System.Text.RegularExpressions.Regex.IsMatch(id, @"^[A-Za-z0-9\-]+$") ?
-                id : GetIDFromUrl(id);
+            return id == null ? null : (System.Text.RegularExpressions.Regex.IsMatch(id, @"^[A-Za-z0-9\-]+$") ?
+                id : GetIDFromUrl(id));
         }
         
         public ClientVersion Version
