@@ -35,6 +35,10 @@ namespace MusicBrainz
     {
         private string artist;
         private string title;
+        private string album;
+        private string asin;
+        private int track_num;
+        private int track_count;
         private int index;
         private int length;
         
@@ -44,6 +48,10 @@ namespace MusicBrainz
             this.length = length;
         }
         
+        internal SimpleTrack()
+        {
+        }
+        
         public override string ToString()
         {
             return String.Format("{0}: {1} - {2} ({3:00}:{4:00})",
@@ -55,17 +63,37 @@ namespace MusicBrainz
                 return artist;
             }
             
-            set {
+            internal set {
                 artist = value;
             }
         }
+                
+        public string Album {
+            get {
+                return album;
+            }
+            
+            internal set {
+                album = value;
+            }
+        }
+                        
+        public string Asin {
+            get {
+                return asin;
+            }
+            
+            internal set {
+                asin = value;
+            }
+        }
         
         public string Title {
             get {
                 return title;
             }
             
-            set {
+            internal set {
                 title = value;
             }
         }
@@ -75,17 +103,37 @@ namespace MusicBrainz
                 return index;
             }
             
-            set {
+            internal set {
                 index = value;
             }
         }
+                
+        public int TrackNumber {
+            get {
+                return track_num;
+            }
+            
+            internal set {
+                track_num = value;
+            }
+        }
+                
+        public int TrackCount {
+            get {
+                return track_count;
+            }
+            
+            internal set {
+                track_count = value;
+            }
+        }
         
         public int Length {
             get {
                 return length;
             }
             
-            set {
+            internal set {
                 length = value;
             }
         }
