@@ -34,6 +34,7 @@ using Gtk;
 using Sql;
 
 using Banshee.Base;
+using Banshee.Sources;
 
 namespace Banshee
 {
@@ -55,8 +56,6 @@ namespace Banshee
         private RepeatMode repeat = RepeatMode.None;
         private bool shuffle = false;
         
-        public Source Source;
-        
         public event EventHandler Updated;
         
         public static int NextUid
@@ -70,6 +69,9 @@ namespace Banshee
         {
             trackInfoQueue = new ArrayList();
             GLib.Timeout.Add(300, new GLib.TimeoutHandler(OnIdle));
+            SourceManager.ActiveSourceChanged += delegate(SourceEventArgs args) {
+                ReloadSource();
+            };
         }
     
         private void SyncPlayingIter()
@@ -146,52 +148,11 @@ namespace Banshee
             }
         }
         
-        public void LoadFromLocalQueue()
-        {
-            ClearModel();
-            foreach(TrackInfo ti in LocalQueueSource.Instance.Tracks) {
-                AddTrack(ti, false);
-            }
-        }
-
-        public void LoadFromPlaylist(string name)
-        {
-            ClearModel();
-            PlaylistLoadTransaction loader = new PlaylistLoadTransaction(name);
-            loader.HaveTrackInfo += OnLoaderHaveTrackInfo;
-            Core.Library.TransactionManager.Register(loader);
-        }
-        
-        public void LoadFromLibrary()
+        public void ReloadSource()
         {
             ClearModel();
             
-            foreach(TrackInfo ti in Core.Library.Tracks.Values) {
-                AddTrack(ti, false);
-            }
-            
-            SyncPlayingIter();
-            RaiseUpdated(this, new EventArgs());
-        }
-        
-        public void LoadFromDapSource(DapSource dapSource)
-        {
-            ClearModel();
-            
-            foreach(TrackInfo track in dapSource.Device) {
-                AddTrack(track);
-            }
-            
-            SyncPlayingIter();
-        }
-        
-        public void LoadFromAudioCdSource(AudioCdSource cdSource)
-        {    
-            ClearModel();
-            
-            AudioCdDisk disk = cdSource.Disk;
-            
-            foreach(AudioCdTrackInfo track in disk.Tracks) {
+            foreach(TrackInfo track in SourceManager.ActiveSource.Tracks) {
                 AddTrack(track);
             }
             
@@ -228,7 +189,7 @@ namespace Banshee
             if(ti == null)
                 return;
                 
-            Core.Instance.PlayerInterface.PlayFile(ti);
+            PlayerCore.UserInterface.PlayFile(ti);
             GetIter(out playingIter, path);
         }
         
@@ -239,7 +200,7 @@ namespace Banshee
                 return;
                 
             if(ti.CanPlay) {
-                Core.Instance.PlayerInterface.PlayFile(ti);
+                PlayerCore.UserInterface.PlayFile(ti);
                 playingIter = iter;
             } else {
                 playingIter = iter;
@@ -364,59 +325,50 @@ namespace Banshee
 
         private bool GetRandomTrackIter(out TreeIter iter)
         {
-            int randIndex = Core.Instance.Random.Next(0, Count());
+            const double HOVER_FREQUENCY = 0.60;
+
+            if(SourceManager.ActiveSource is LibrarySource
+               && !playingIter.Equals(TreeIter.Zero)
+               && Count () == Globals.Library.Tracks.Count) {   // XXX: Gross way to check that there isn't a search active
+                TrackInfo last_track = IterTrackInfo(playingIter);
+                
+                if(Globals.Random.NextDouble() < HOVER_FREQUENCY) {
+                    string query = "SELECT TrackID FROM Tracks "
+                        + "WHERE Genre = '" + Statement.EscapeQuotes(last_track.Genre) + "' "
+                        + "ORDER BY RANDOM() LIMIT 1";
+
+                    int id = 0;
+                    try {
+                        id = Convert.ToInt32(Globals.Library.Db.QuerySingle(query) as string);
+                    } catch { } 
+    
+                    if(id > 0) {
+                        LibraryTrackInfo track = Globals.Library.GetTrack(id);
+                        if (track != null) {
+                            iter = track.TreeIter;
+                            return true;
+                        }
+                    }
+                }
+            }
+
+            int randIndex = Globals.Random.Next(0, Count());
             return IterNthChild(out iter, randIndex);
         }
         
         public void ClearModel()
         {
-            Core.Library.TransactionManager.Cancel(typeof(FileLoadTransaction));
             trackInfoQueue.Clear();
         
             totalDuration = new TimeSpan(0);
             playingIter = TreeIter.Zero;
             Clear();
                 
-            if(Updated != null && ThreadAssist.InMainThread)
+            if(Updated != null && ThreadAssist.InMainThread) {
                 Updated(this, new EventArgs());
-        }
-        
-        /*public void RemoveTrack(TreePath path)
-        {
-            TrackInfo ti = PathTrackInfo(path);
-            TreeIter iter;
-            
-            if(!GetIter(out iter, path))
-                return;
-                
-            if(Source.Type == SourceType.Playlist 
-                || Source.Type == SourceType.Library) {
-                Statement query = new Delete("PlaylistEntries")
-                    + new Where("TrackID", Op.EqualTo, ti.TrackId);
-                try {
-                    Core.Library.Db.Execute(query);
-                } catch(Exception) {}
-                
-                
-                if(Source.Type == SourceType.Library) {
-                    Statement query2 = new Delete("Tracks")
-                        + new Where("TrackID", Op.EqualTo, ti.TrackId);
-                    try {
-                        Core.Library.Db.Execute(query2);
-                    } catch(Exception) {}
-                }
             }
-            
-            RemoveTrack(ref iter, ti);
         }
         
-        private void RemoveTrack(ref TreeIter iter, TrackInfo ti)
-        {
-            randomQueue.Remove(iter);
-            Remove(ref iter);
-        }
-        */
-        
         public void RemoveTrack(ref TreeIter iter)
         {
             TrackInfo ti = IterTrackInfo(iter);
@@ -426,6 +378,17 @@ namespace Banshee
             RaiseUpdated(this, new EventArgs());
         }
         
+        public void RemoveTrack(TrackInfo track)
+        {
+        
+        }
+        
+        public int GetIterIndex(TreeIter iter)
+        {
+            TreePath path = GetPath(iter);
+            return path == null ? - 1 : path.Indices[0];
+        }
+        
         // --- Event Raise Handlers ---
 
         private void RaiseUpdated(object o, EventArgs args)
